import os
import shutil
import unittest
from glob import glob

from omrdatasettools.downloaders import DatasetDownloader
from omrdatasettools.downloaders.HomusDatasetDownloader import HomusDatasetDownloader


class DatasetDownloaderTest(unittest.TestCase):
    def test_download_and_extract_homus_v1_dataset_expect_folder_to_be_created(self):
        destination_directory = "HOMUS"
        downloader = HomusDatasetDownloader(".", version=1)
        zip_file = downloader.get_dataset_filename()
        number_of_samples_in_the_dataset = 15200
        target_file_extension = "*.txt"

        self.download_dataset_and_verify_correct_extraction(destination_directory, number_of_samples_in_the_dataset,
                                                            target_file_extension, zip_file,
                                                            downloader)

    def test_download_and_extract_homus_v2_dataset_expect_folder_to_be_created(self):
        destination_directory = "HOMUS"
        downloader = HomusDatasetDownloader(".", version=1)
        zip_file = downloader.get_dataset_filename()
        number_of_samples_in_the_dataset = 15200
        target_file_extension = "*.txt"

        self.download_dataset_and_verify_correct_extraction(destination_directory, number_of_samples_in_the_dataset,
                                                            target_file_extension, zip_file,
                                                            downloader)

    def download_dataset_and_verify_correct_extraction(self, destination_directory: str,
                                                       number_of_samples_in_the_dataset: int,
                                                       target_file_extension: str, zip_file: str,
                                                       dataset_downloader: DatasetDownloader):
        # Arrange and Cleanup
        if os.path.exists(zip_file):
            os.remove(zip_file)
        shutil.rmtree(destination_directory, ignore_errors=True)

        # Act
        dataset_downloader.download_and_extract_dataset()

        # Assert
        all_files = [y for x in os.walk(destination_directory) for y in glob(os.path.join(x[0], target_file_extension))]
        actual_number_of_files = len(all_files)
        self.assertEqual(number_of_samples_in_the_dataset, actual_number_of_files)
        self.assertTrue(os.path.exists(zip_file))

        # Cleanup
        os.remove(zip_file)
        shutil.rmtree(destination_directory, ignore_errors=True)


if __name__ == '__main__':
    unittest.main()



import argparse
import os

from omrdatasettools.downloaders.DatasetDownloader import DatasetDownloader


class HomusDatasetDownloader(DatasetDownloader):
    """ Downloads the HOMUS dataset
        http://grfia.dlsi.ua.es/homus/
        License unspecified
    """

    def __init__(self, destination_directory: str, version: int = 2):
        """
        Create and initializes a new dataset.
        :param destination_directory: The root directory, into which the data will be copied.
        :param version: Version of the HOMUS dataset, can either be 1 (official, original) or 2 (version with bug-fixes)
        """
        super().__init__(destination_directory)
        self.version = version

    def get_dataset_download_url(self) -> str:
        if self.version == 1:
            # Version 1.0 - official version
            return "http://grfia.dlsi.ua.es/homus/HOMUS.zip"
        elif self.version == 2:
            # Version 2.0 - version with bug-fixes, see https://github.com/apacha/Homus
            return "https://owncloud.tuwien.ac.at/index.php/s/5qVjo9HGGN1bN4I/download"

    def get_dataset_filename(self) -> str:
        if self.version == 1:
            return "HOMUS.zip"
        if self.version == 2:
            return "HOMUS-2.0.zip"

    def download_and_extract_dataset(self):
        if not os.path.exists(self.get_dataset_filename()):
            print("Downloading HOMUS Dataset (Version {0})...".format(self.version))
            self.download_file(self.get_dataset_download_url(), self.get_dataset_filename())

        print("Extracting HOMUS Dataset...")
        self.extract_dataset(self.destination_directory)


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "--dataset_directory",
        type=str,
        default="../data/homus_raw",
        help="The directory, where the extracted dataset will be copied to")

    flags, unparsed = parser.parse_known_args()

    dataset = HomusDatasetDownloader(flags.dataset_directory)
    dataset.download_and_extract_dataset()



from distutils.core import setup

from setuptools import find_packages

setup(
    name='omrdatasettools',
    packages=find_packages('.'),
    version='0.4',
    description='A collection of tools that simplify the downloading and handling of datasets used for Optical Music Recognition (OMR).',
    author='Alexander Pacha',
    author_email='alexander.pacha@tuwien.ac.at',
    license='MIT',
    url='https://github.com/apacha/omr-datasets',  # use the URL to the github repo
    download_url='https://github.com/apacha/omr-datasets/archive/0.2.tar.gz',
    keywords=['optical music recognition', 'downloading', 'extracting', 'omr', 'generating', 'dataset', 'preprocessing'],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',

        'Topic :: Scientific/Engineering :: Image Recognition',
        'Topic :: Scientific/Engineering :: Visualization',
        'Topic :: Multimedia :: Graphics',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
